"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
class MemoryCache {
    constructor() {
        this.cache = {};
        this.invalidate = this.invalidate.bind(this);
        setInterval(this.invalidate, 60000);
    }
    get(key) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.cache[key])
                return null;
            if (this.isExpired(this.cache[key])) {
                delete this.cache[key];
                return null;
            }
            return this.cache[key].value;
        });
    }
    set(key, value, ms) {
        return __awaiter(this, void 0, void 0, function* () {
            this.cache[key] = {
                value,
                expire: ms ? Date.now() + ms : null
            };
        });
    }
    invalidate() {
        for (const key in this.cache) {
            if (this.isExpired(this.cache[key])) {
                delete this.cache[key];
            }
        }
    }
    isExpired(cacheEntry) {
        return cacheEntry.expire && cacheEntry.expire < Date.now();
    }
}
exports.MemoryCache = MemoryCache;
//# sourceMappingURL=memory-cache.js.map