import { Tokenizer } from "./tokenizer";
import * as request from "request";
import { RequestCallback } from "request";
import { StreamFactory } from "./stream-factory";
import { CacheConfiguration } from "./cache-factory";
import { RetryInputConfiguration } from "./retry";
import { SchemaStringifierConfiguration } from "./schema-stringifier";
declare type HTTP_METHOD = 'get' | 'post' | 'put' | 'del' | 'delete' | 'patch' | 'head' | 'options';
interface RequestOptions extends request.CoreOptions {
    url: string;
    method: HTTP_METHOD;
    headers?: {
        [key: string]: string;
    };
    body?: object | string;
}
interface RouteConfiguration {
    [key: string]: object | string | number | boolean | undefined;
    identifier?: string;
    cache?: CacheConfiguration | boolean;
    holder?: boolean;
    retry?: RetryInputConfiguration | boolean | number;
    schema?: SchemaStringifierConfiguration;
}
declare class RequestManager {
    private streams;
    private streamFactory;
    private tokenizer;
    private requestId;
    constructor(streamFactory: StreamFactory, tokenizer: Tokenizer);
    register(name: string, routeConfiguration: RouteConfiguration): (requestOptions: RequestOptions, cb: request.RequestCallback) => void;
    unregister(name: string): void;
    handle(name: string, requestOptions: RequestOptions, cb: RequestCallback): void;
    isRouteRegistered(name: string): boolean;
    private addStream;
}
export { HTTP_METHOD, RequestOptions, RouteConfiguration, RequestManager };
