import { RequestManager, RequestOptions, RouteConfiguration } from "./request-manager";
import { CoreOptions, RequestCallback } from "request";
import { RequestWrapper } from "./request-wrapper";
import { CacheFactory, CachePlugin } from "./cache-factory";
declare class Warden {
    static debug: boolean;
    private requestManager;
    private requestWrapper;
    private cacheFactory;
    constructor(requestManager: RequestManager, requestWrapper: RequestWrapper, cacheFactory: CacheFactory);
    debug: boolean;
    /**
     * Registers a new route to Warden
     * @param name
     * @param routeConfiguration
     */
    register(name: string, routeConfiguration: RouteConfiguration): (requestOptions: RequestOptions, cb: RequestCallback) => void;
    /**
     * Sends a new HTTP Request using warden
     * @param name
     * @param requestOptions
     * @param cb
     */
    request(name: string, requestOptions: RequestOptions, cb: RequestCallback): void;
    /**
     * Sets default request configuration
     * @param options
     */
    requestConfig(options: CoreOptions): void;
    /**
     * Checks whether route is registered
     * @param name
     */
    isRouteRegistered(name: string): boolean;
    /**
     * Unregisters Route
     * @param name
     */
    unregisterRoute(name: string): void;
    /**
     * @param name
     * @param plugin
     */
    registerCachePlugin(name: string, plugin: CachePlugin | (new () => CachePlugin)): void;
}
export { Warden };
