"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class Warden {
    constructor(requestManager, requestWrapper, cacheFactory) {
        this.requestManager = requestManager;
        this.requestWrapper = requestWrapper;
        this.cacheFactory = cacheFactory;
        this.requestWrapper.wrap(requestManager);
    }
    get debug() {
        return Warden.debug;
    }
    set debug(enabled) {
        Warden.debug = enabled;
    }
    /**
     * Registers a new route to Warden
     * @param name
     * @param routeConfiguration
     */
    register(name, routeConfiguration) {
        return this.requestManager.register(name, routeConfiguration);
    }
    /**
     * Sends a new HTTP Request using warden
     * @param name
     * @param requestOptions
     * @param cb
     */
    request(name, requestOptions, cb) {
        return this.requestManager.handle(name, requestOptions, cb);
    }
    /**
     * Sets default request configuration
     * @param options
     */
    requestConfig(options) {
        this.requestWrapper.config(options);
    }
    /**
     * Checks whether route is registered
     * @param name
     */
    isRouteRegistered(name) {
        return this.requestManager.isRouteRegistered(name);
    }
    /**
     * Unregisters Route
     * @param name
     */
    unregisterRoute(name) {
        this.requestManager.unregister(name);
    }
    /**
     * @param name
     * @param plugin
     */
    registerCachePlugin(name, plugin) {
        this.cacheFactory.register(name, plugin);
    }
}
Warden.debug = false;
exports.Warden = Warden;
//# sourceMappingURL=warden.js.map